'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var reactTable = require('react-table');
var material = require('@mui/material');
var ArrowForwardIosIcon = _interopDefault(require('@mui/icons-material/ArrowForwardIos'));

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var defaultOptions = {
  enableFilters: false,
  enablePagination: 'bottom',
  enableSearch: true,
  enableSorting: true,
  showFooter: true,
  showHead: true,
  showToolbar: true
};

var _excluded = ["children", "columns", "data", "options"];
var MaterialReactTableContext = /*#__PURE__*/React.createContext({});
var MaterialReactTableProvider = function MaterialReactTableProvider(_ref) {
  var children = _ref.children,
      columns = _ref.columns,
      data = _ref.data,
      options = _ref.options,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded);

  var tableInstance = reactTable.useTable({
    columns: columns,
    data: data
  }, reactTable.useSortBy, reactTable.useExpanded, reactTable.usePagination);
  return React__default.createElement(MaterialReactTableContext.Provider, {
    value: _extends({
      options: _extends({}, defaultOptions, options),
      tableInstance: tableInstance
    }, rest)
  }, children);
};
var useMaterialReactTable = function useMaterialReactTable() {
  return React.useContext(MaterialReactTableContext);
};

var MRT_TableHeadCell = function MRT_TableHeadCell(_ref) {
  var _column$columns$lengt, _column$columns;

  var column = _ref.column;
  var isParentHeader = ((_column$columns$lengt = column == null ? void 0 : (_column$columns = column.columns) == null ? void 0 : _column$columns.length) != null ? _column$columns$lengt : 0) > 0;
  return React__default.createElement(material.TableCell, Object.assign({
    align: isParentHeader ? 'center' : 'left',
    style: {
      fontWeight: 'bold !important'
    },
    variant: "head"
  }, column.getHeaderProps(column.getSortByToggleProps())), React__default.createElement(material.TableSortLabel, {
    active: column.isSorted,
    direction: column.isSortedDesc && column.isSortedDesc ? 'desc' : 'asc'
  }, column.render('Header')));
};

var MRT_TableHeadRow = function MRT_TableHeadRow(_ref) {
  var headerGroup = _ref.headerGroup;

  var _useMaterialReactTabl = useMaterialReactTable(),
      renderDetailPanel = _useMaterialReactTabl.renderDetailPanel;

  return React__default.createElement(material.TableRow, Object.assign({}, headerGroup.getHeaderGroupProps()), renderDetailPanel && React__default.createElement(material.TableCell, {
    style: {
      width: '2rem'
    }
  }), headerGroup.headers.map(function (column, index) {
    return React__default.createElement(MRT_TableHeadCell, {
      key: index + "-" + column.id,
      column: column
    });
  }));
};

var MRT_TablePagination = function MRT_TablePagination() {
  var _useMaterialReactTabl = useMaterialReactTable(),
      tableInstance = _useMaterialReactTabl.tableInstance,
      tablePaginationProps = _useMaterialReactTabl.tablePaginationProps;

  var handleChangeRowsPerPage = function handleChangeRowsPerPage(event) {
    tableInstance.setPageSize(+event.target.value);
    tableInstance.gotoPage(0);
  };

  return React__default.createElement(material.TableRow, null, React__default.createElement(material.TablePagination, Object.assign({
    colSpan: tableInstance.visibleColumns.length + 10,
    count: tableInstance.rows.length,
    onPageChange: function onPageChange(_, newPage) {
      return tableInstance.gotoPage(newPage);
    },
    onRowsPerPageChange: handleChangeRowsPerPage,
    page: tableInstance.state.pageIndex,
    rowsPerPage: tableInstance.state.pageSize,
    showFirstButton: tableInstance.rows.length / tableInstance.state.pageSize > 2,
    showLastButton: tableInstance.rows.length / tableInstance.state.pageSize > 2
  }, tablePaginationProps)));
};

var MRT_TableHead = function MRT_TableHead() {
  var _useMaterialReactTabl = useMaterialReactTable(),
      tableInstance = _useMaterialReactTabl.tableInstance,
      tableHeadProps = _useMaterialReactTabl.tableHeadProps,
      options = _useMaterialReactTabl.options;

  return React__default.createElement(material.TableHead, Object.assign({}, tableHeadProps), ['top', 'both'].includes(options.enablePagination.toString()) && React__default.createElement(MRT_TablePagination, null), tableInstance.headerGroups.map(function (headerGroup, index) {
    return React__default.createElement(MRT_TableHeadRow, {
      key: index + "-" + headerGroup.id,
      headerGroup: headerGroup
    });
  }));
};

var MRT_TableBodyCell = function MRT_TableBodyCell(_ref) {
  var cell = _ref.cell;
  return React__default.createElement(material.TableCell, Object.assign({
    variant: "body"
  }, cell.getCellProps()), cell.render('Cell'));
};

var MRT_TableDetailPanel = function MRT_TableDetailPanel(_ref) {
  var row = _ref.row;

  var _useMaterialReactTabl = useMaterialReactTable(),
      tableInstance = _useMaterialReactTabl.tableInstance,
      renderDetailPanel = _useMaterialReactTabl.renderDetailPanel;

  return React__default.createElement(material.TableRow, Object.assign({}, row.getToggleRowExpandedProps()), React__default.createElement(material.TableCell, {
    colSpan: tableInstance.visibleColumns.length + 10,
    style: {
      paddingBottom: row.isExpanded ? '1rem' : 0,
      paddingTop: row.isExpanded ? '1rem' : 0,
      transition: 'padding 0.2s'
    }
  }, React__default.createElement(material.Collapse, {
    "in": row.isExpanded
  }, renderDetailPanel == null ? void 0 : renderDetailPanel(row))));
};

var MRT_TableExpandButton = function MRT_TableExpandButton(_ref) {
  var row = _ref.row;
  return React__default.createElement(material.TableCell, {
    style: {
      width: '2rem'
    },
    size: "small",
    variant: "head"
  }, React__default.createElement(material.IconButton, {
    onClick: function onClick() {
      return row.toggleRowExpanded();
    },
    size: "small"
  }, React__default.createElement(ArrowForwardIosIcon, {
    fontSize: "small",
    style: {
      transform: row.isExpanded ? 'rotate(90deg)' : 'rotate(0)',
      transition: 'transform 0.2s'
    }
  })));
};

var MRT_TableBodyRow = function MRT_TableBodyRow(_ref) {
  var row = _ref.row;

  var _useMaterialReactTabl = useMaterialReactTable(),
      renderDetailPanel = _useMaterialReactTabl.renderDetailPanel;

  return React__default.createElement(React__default.Fragment, null, React__default.createElement(material.TableRow, Object.assign({}, row.getRowProps()), renderDetailPanel && React__default.createElement(MRT_TableExpandButton, {
    row: row
  }), row.cells.map(function (cell, index) {
    return React__default.createElement(MRT_TableBodyCell, {
      key: index + "-" + cell.value,
      cell: cell
    });
  })), renderDetailPanel && React__default.createElement(MRT_TableDetailPanel, {
    row: row
  }));
};

var MRT_TableBody = function MRT_TableBody() {
  var _useMaterialReactTabl = useMaterialReactTable(),
      tableInstance = _useMaterialReactTabl.tableInstance;

  return React__default.createElement(material.TableBody, Object.assign({}, tableInstance.getTableBodyProps()), tableInstance.page.map(function (row, index) {
    tableInstance.prepareRow(row);
    return React__default.createElement(MRT_TableBodyRow, {
      key: index + "-" + row.id,
      row: row
    });
  }));
};

var TableCell = /*#__PURE__*/material.styled(material.TableCell)({
  fontWeight: 'bold'
});
var MRT_TableFooterCell = function MRT_TableFooterCell(_ref) {
  var _column$columns$lengt, _column$columns;

  var column = _ref.column;
  var isParentHeader = ((_column$columns$lengt = column == null ? void 0 : (_column$columns = column.columns) == null ? void 0 : _column$columns.length) != null ? _column$columns$lengt : 0) > 0;
  return React__default.createElement(TableCell, Object.assign({
    align: isParentHeader ? 'center' : 'left',
    variant: "head"
  }, column.getFooterProps()), column.render('Footer'));
};

var MRT_TableFooterRow = function MRT_TableFooterRow(_ref) {
  var footerGroup = _ref.footerGroup;

  var _useMaterialReactTabl = useMaterialReactTable(),
      renderDetailPanel = _useMaterialReactTabl.renderDetailPanel;

  return React__default.createElement(material.TableRow, Object.assign({}, footerGroup.getFooterGroupProps()), renderDetailPanel && React__default.createElement(material.TableCell, {
    style: {
      width: '2rem'
    }
  }), footerGroup.headers.map(function (column, index) {
    return React__default.createElement(MRT_TableFooterCell, {
      key: index + "-" + column.id,
      column: column
    });
  }));
};

var MRT_TableFooter = function MRT_TableFooter() {
  var _useMaterialReactTabl = useMaterialReactTable(),
      tableInstance = _useMaterialReactTabl.tableInstance,
      tableFooterProps = _useMaterialReactTabl.tableFooterProps,
      options = _useMaterialReactTabl.options;

  var hasFooterGroups = tableInstance.columns.some(function (c) {
    return c.depth === 0 && !!c.Footer;
  });
  return React__default.createElement(material.TableFooter, Object.assign({}, tableFooterProps), hasFooterGroups && tableInstance.footerGroups.map(function (footerGroup, index) {
    return React__default.createElement(MRT_TableFooterRow, {
      key: index + "-" + footerGroup.id,
      footerGroup: footerGroup
    });
  }), options.enablePagination === true || ['bottom', 'both'].includes(options.enablePagination.toString()) && React__default.createElement(MRT_TablePagination, null));
};

var MRT_Table = function MRT_Table() {
  var _useMaterialReactTabl = useMaterialReactTable(),
      tableInstance = _useMaterialReactTabl.tableInstance,
      tableProps = _useMaterialReactTabl.tableProps,
      options = _useMaterialReactTabl.options;

  return React__default.createElement(material.Table, Object.assign({
    stickyHeader: true
  }, tableProps, tableInstance.getTableProps()), options.showHead && React__default.createElement(MRT_TableHead, null), React__default.createElement(MRT_TableBody, null), options.showFooter && React__default.createElement(MRT_TableFooter, null));
};

var MRT_TableContainer = function MRT_TableContainer() {
  var _useMaterialReactTabl = useMaterialReactTable(),
      tableContainerProps = _useMaterialReactTabl.tableContainerProps;

  return React__default.createElement(material.TableContainer, Object.assign({
    component: material.Paper
  }, tableContainerProps), React__default.createElement(MRT_Table, null));
};

var _excluded$1 = ["options"];
var MaterialReactTable = function MaterialReactTable(_ref) {
  var _ref$options = _ref.options,
      options = _ref$options === void 0 ? defaultOptions : _ref$options,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$1);

  return React__default.createElement(MaterialReactTableProvider, Object.assign({
    options: options
  }, rest), React__default.createElement(MRT_TableContainer, null));
};

exports.MaterialReactTable = MaterialReactTable;
//# sourceMappingURL=material-react-table.cjs.development.js.map
